Usage
=====

.. _installation:

Installation
------------

To use TextGrad, first install it using pip:

.. code-block:: console

   $ pip install textgrad[langchain]

If you want to use the LangChain extensions, please use:

.. code-block:: console

    $ pip install textgrad[langchain]
